==> schemacrawler-oracle-16.11.4-sources.jar: schemacrawler/server/oracle/OracleCatalogLoader.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2020, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/
package schemacrawler.server.oracle;

import static java.util.Objects.requireNonNull;
import static us.fatehi.utility.DatabaseUtility.executeScriptFromResource;

import java.sql.Connection;

import schemacrawler.schema.Catalog;
import schemacrawler.tools.catalogloader.SchemaCrawlerCatalogLoader;

public final class OracleCatalogLoader extends SchemaCrawlerCatalogLoader {

  public OracleCatalogLoader() {
    super(OracleDatabaseConnector.DB_SERVER_TYPE.getDatabaseSystemIdentifier());
  }

  @Override
  public Catalog loadCatalog() throws Exception {
    final Connection connection = getConnection();
    requireNonNull(connection, "No connection provided");

    executeScriptFromResource(connection, "/schemacrawler-oracle.before.sql");

    return super.loadCatalog();
  }
}

==> schemacrawler-oracle-16.17.3-sources.jar: schemacrawler/server/oracle/OracleCatalogLoader.java <==
/*
========================================================================
SchemaCrawler
http://www.schemacrawler.com
Copyright (c) 2000-2022, Sualeh Fatehi <sualeh@hotmail.com>.
All rights reserved.
------------------------------------------------------------------------

SchemaCrawler is distributed in the hope that it will be useful, but
WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

SchemaCrawler and the accompanying materials are made available under
the terms of the Eclipse Public License v1.0, GNU General Public License
v3 or GNU Lesser General Public License v3.

You may elect to redistribute this code under any of these licenses.

The Eclipse Public License is available at:
http://www.eclipse.org/legal/epl-v10.html

The GNU General Public License v3 and the GNU Lesser General Public
License v3 are available at:
http://www.gnu.org/licenses/

========================================================================
*/
package schemacrawler.server.oracle;

import static java.util.Objects.requireNonNull;

import java.sql.Connection;

import schemacrawler.tools.catalogloader.BaseCatalogLoader;
import schemacrawler.tools.executable.CommandDescription;
import us.fatehi.utility.database.SqlScript;

public final class OracleCatalogLoader extends BaseCatalogLoader {

  public OracleCatalogLoader() {
    super(new CommandDescription("oracleloader", "Loader for Oracle databases"), -1);
  }

  @Override
  public void loadCatalog() {

    if (!isDatabaseSystemIdentifier(
        OracleDatabaseConnector.DB_SERVER_TYPE.getDatabaseSystemIdentifier())) {
      return;
    }

    final Connection connection = getConnection();
    requireNonNull(connection, "No connection provided");

    SqlScript.executeScriptFromResource("/schemacrawler-oracle.before.sql", connection);
  }
}
